Exception: OllamaChat::OllamaChatQuitError

Inherits:
OllamaChatError show all
Defined in:
lib/ollama_chat.rb

Overview

OllamaChatQuitError is raised to signal a graceful shutdown of the application.

This is typically raised by Chat#quit_app or other commands that need to terminate the main interaction loop cleanly.